@@ -4,11 +4,9 @@ from tqdm import tqdm
 
 from typing import List
 
-from colorama import init as colorama_init
-from colorama import Fore, Back, Style
 from ..utils.github_scanner import query_matching_repos
 from ..utils.github_entities import Team
-
+from ..ensures import ensure_gh_token
 from ..config.github import config_github, config_grant_read_access
 
 # Use a "team slug"
@@ -23,7 +21,9 @@ from ..config.github import config_github, config_grant_read_access
 def grant_read_access(hw_title, token, org, team):
     '''Grant read access right of TA's group to students' homework repo'''
     print("start script")
-    colorama_init()
+
+    ensure_gh_token(token)
+
     teaching_team = Team(org, team, token)
 
     repos = query_matching_repos(org,
